==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/structllarp_1_1quic_1_1Path.md <==
---
title: llarp::quic::Path

---

# llarp::quic::Path





## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**() =default |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & laddr, const [Address](Classes/classllarp_1_1quic_1_1Address.md) & raddr) |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**(const [Path](Classes/structllarp_1_1quic_1_1Path.md) & p) |
| [Path](Classes/structllarp_1_1quic_1_1Path.md) & | **[operator=](Classes/structllarp_1_1quic_1_1Path.md#function-operator=)**(const [Path](Classes/structllarp_1_1quic_1_1Path.md) & p) |
| | **[operator ngtcp2_path *](Classes/structllarp_1_1quic_1_1Path.md#function-operator-ngtcp2-path-*)**() |
| | **[operator const ngtcp2_path *](Classes/structllarp_1_1quic_1_1Path.md#function-operator-const-ngtcp2-path-*)**() const |
| std::string | **[to_string](Classes/structllarp_1_1quic_1_1Path.md#function-to-string)**() const |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| ngtcp2_path | **[path](Classes/structllarp_1_1quic_1_1Path.md#variable-path)**  |
| const [Address](Classes/classllarp_1_1quic_1_1Address.md) &const [Address](Classes/classllarp_1_1quic_1_1Address.md) & | **[remote](Classes/structllarp_1_1quic_1_1Path.md#variable-remote)**  |

## Public Functions Documentation

### function Path

```cpp
Path() =default
```


### function Path

```cpp
inline Path(
    const Address & laddr,
    const Address & raddr
)
```


### function Path

```cpp
inline Path(
    const Path & p
)
```


### function operator=

```cpp
inline Path & operator=(
    const Path & p
)
```


### function operator ngtcp2_path *

```cpp
inline operator ngtcp2_path *()
```


### function operator const ngtcp2_path *

```cpp
inline operator const ngtcp2_path *() const
```


### function to_string

```cpp
std::string to_string() const
```


## Public Attributes Documentation

### variable path

```cpp
ngtcp2_path path {{local_, local_.sockaddr_size()}, {remote_, remote_.sockaddr_size()}, nullptr};
```


### variable remote

```cpp
const Address &const Address & remote = remote_;
```


-------------------------------

Updated on 2022-05-31 at 02:25:20 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/structllarp_1_1quic_1_1Path.md <==
---
title: llarp::quic::Path

---

# llarp::quic::Path





## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**() =default |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**(const [Address](Classes/classllarp_1_1quic_1_1Address.md) & laddr, const [Address](Classes/classllarp_1_1quic_1_1Address.md) & raddr) |
| | **[Path](Classes/structllarp_1_1quic_1_1Path.md#function-path)**(const [Path](Classes/structllarp_1_1quic_1_1Path.md) & p) |
| [Path](Classes/structllarp_1_1quic_1_1Path.md) & | **[operator=](Classes/structllarp_1_1quic_1_1Path.md#function-operator=)**(const [Path](Classes/structllarp_1_1quic_1_1Path.md) & p) |
| template <typename T ,std::enable_if_t< std::is_same_v< T, ngtcp2_path >, int >  =0\> <br>| **[operator T*](Classes/structllarp_1_1quic_1_1Path.md#function-operator-t*)**() |
| template <typename T ,std::enable_if_t< std::is_same_v< T, ngtcp2_path >, int >  =0\> <br>| **[operator const T *](Classes/structllarp_1_1quic_1_1Path.md#function-operator-const-t-*)**() const |
| std::string | **[ToString](Classes/structllarp_1_1quic_1_1Path.md#function-tostring)**() const |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| ngtcp2_path | **[path](Classes/structllarp_1_1quic_1_1Path.md#variable-path)**  |
| const [Address](Classes/classllarp_1_1quic_1_1Address.md) &const [Address](Classes/classllarp_1_1quic_1_1Address.md) & | **[remote](Classes/structllarp_1_1quic_1_1Path.md#variable-remote)**  |

## Public Functions Documentation

### function Path

```cpp
Path() =default
```


### function Path

```cpp
inline Path(
    const Address & laddr,
    const Address & raddr
)
```


### function Path

```cpp
inline Path(
    const Path & p
)
```


### function operator=

```cpp
inline Path & operator=(
    const Path & p
)
```


### function operator T*

```cpp
template <typename T ,
std::enable_if_t< std::is_same_v< T, ngtcp2_path >, int >  =0>
inline operator T*()
```


### function operator const T *

```cpp
template <typename T ,
std::enable_if_t< std::is_same_v< T, ngtcp2_path >, int >  =0>
inline operator const T *() const
```


### function ToString

```cpp
std::string ToString() const
```


## Public Attributes Documentation

### variable path

```cpp
ngtcp2_path path {{local_, local_.sockaddr_size()}, {remote_, remote_.sockaddr_size()}, nullptr};
```


### variable remote

```cpp
const Address &const Address & remote = remote_;
```


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
